@@ -1,10 +1,11 @@
 import functools
 import json
 import re
-from os import path
+from pathlib import Path
 from typing import Any, Dict
 
 from annet.annlib.netdev.db import find_true_sequences, get_db
+from annet.lib import get_context
 
 
 @functools.lru_cache(None)
@@ -23,6 +24,7 @@ def _prepare_db() -> Dict[str, Any]:
         from library.python import resource
         raw = json.loads(resource.resfs_read("contrib/python/annet/annet/annlib/netdev/devdb/data/devdb.json").decode("utf-8"))
     except ImportError:
-        with open(path.join(path.dirname(__file__), "data", "devdb.json"), "r") as f:
+        devdb_file = Path(get_context().get("devdb", {}).get("path", Path(__file__).parent / "data" / "devdb.json"))
+        with devdb_file.open("r", encoding="utf-8") as f:
             raw = json.load(f)
     return {tuple(seq.split(".")): re.compile(regexp) for (seq, regexp) in raw.items()}
