@@ -25,11 +25,12 @@ from typing import (
 import tabulate
 from contextlog import get_logger
 
-from annet import generators, implicit, patching, tabparser, tracing
+from annet import generators, implicit, patching, tracing
+from annet.vendors import tabparser
 from annet.annlib import jsontools
 from annet.annlib.rbparser.acl import compile_acl_text
 from annet.cli_args import DeployOptions, GenOptions, ShowGenOptions
-from annet.deploy import scrub_config, get_fetcher
+from annet.deploy import get_fetcher, scrub_config
 from annet.filtering import Filterer
 from annet.generators import (
     BaseGenerator,
@@ -40,12 +41,12 @@ from annet.generators import (
     PartialGenerator,
     RefGenerator,
 )
-from annet.lib import merge_dicts, percentile, do_async
+from annet.lib import do_async, merge_dicts, percentile
 from annet.output import output_driver_connector
-from annet.parallel import Parallel
-from annet.storage import Device, Storage, storage_connector
+from annet.storage import Device, Storage
 from annet.tracing import tracing_connector
 from annet.types import OldNewResult
+from annet.vendors import registry_connector
 
 
 # Вывод всех генераторов вместе.
@@ -162,7 +163,7 @@ def _old_new_per_device(ctx: OldNewDeviceContext, device: Device, filterer: Filt
         if ctx.config != "empty":
             old = tabparser.parse_to_tree(
                 text=text,
-                splitter=tabparser.make_formatter(device.hw).split,
+                splitter=registry_connector.get().match(device.hw).make_formatter().split,
             )
         if not old:
             res = generators.run_partial_initial(device)
@@ -258,38 +259,19 @@ def _old_new_per_device(ctx: OldNewDeviceContext, device: Device, filterer: Filt
 
         entire_results = res.entire_results
         json_fragment_results = res.json_fragment_results
-        old_json_fragment_files = old_files.json_fragment_files
 
         new_files = res.new_files()
-        new_json_fragment_files = res.new_json_fragment_files(old_json_fragment_files)
 
-        filters: List[str] = []
-        filters_text = build_filter_text(filterer, device, ctx.stdin, ctx.args, ctx.config)
-        if filters_text:
-            filters = filters_text.split("\n")
+        filters = None
+        if filters_text := build_filter_text(filterer, device, ctx.stdin, ctx.args, ctx.config):
+            filters = filters_text.removesuffix("\n").split("\n")
 
-            for file_name in new_json_fragment_files:
-                if new_json_fragment_files.get(file_name) is not None:
-                    new_json_fragment_files = _update_json_config(
-                        new_json_fragment_files,
-                        file_name,
-                        jsontools.apply_acl_filters(new_json_fragment_files[file_name][0], filters)
-                    )
-            for file_name in old_json_fragment_files:
-                if old_json_fragment_files.get(file_name) is not None:
-                    old_json_fragment_files[file_name] = jsontools.apply_acl_filters(old_json_fragment_files[file_name], filters)
+        old_json_fragment_files = old_files.json_fragment_files.copy()
+        new_json_fragment_files = res.new_json_fragment_files(old_json_fragment_files, filters=filters)
 
         if ctx.args.acl_safe:
             safe_new_files = res.new_files(safe=True)
-            safe_new_json_fragment_files = res.new_json_fragment_files(old_json_fragment_files, safe=True)
-            if filters:
-                for file_name in safe_new_json_fragment_files:
-                    if safe_new_json_fragment_files.get(file_name):
-                        safe_new_json_fragment_files = _update_json_config(
-                            safe_new_json_fragment_files,
-                            file_name,
-                            jsontools.apply_acl_filters(safe_new_json_fragment_files[file_name][0], filters)
-                        )
+            safe_new_json_fragment_files = res.new_json_fragment_files(old_json_fragment_files, safe=True, filters=filters)
 
     if ctx.args.profile:
         perf = res.perf_mesures()
@@ -321,13 +303,6 @@ def _old_new_per_device(ctx: OldNewDeviceContext, device: Device, filterer: Filt
     )
 
 
-def _update_json_config(json_files, file_name, new_config):
-    file = list(json_files[file_name])
-    file[0] = new_config
-    json_files[file_name] = tuple(file)
-    return json_files
-
-
 @dataclasses.dataclass
 class DeviceDownloadedFiles:
     # map file path to file content for entire generators
@@ -638,7 +613,7 @@ def _existing_cfg_file_name(config_dir: str, device) -> Optional[str]:
 
 
 def format_config_blocks(config, hw, indent, _level=0):
-    formatter = tabparser.make_formatter(hw, indent=indent)
+    formatter = registry_connector.get().match(hw).make_formatter(indent=indent)
     return formatter.join(config)
 
 
