@@ -15,13 +15,14 @@ import tempfile
 import time
 import traceback
 import warnings
-from typing import Any, List, Optional, Type
+from typing import Any, List, Optional, Type, Callable
 from uuid import uuid4
 
 from contextlog import get_logger
 
 import annet
 from annet import tracing
+from annet.connectors import Connector
 from annet.lib import catch_ctrl_c, find_exc_in_stack
 from annet.output import capture_output
 from annet.tracing import tracing_connector
@@ -38,6 +39,20 @@ class PoolWorkerTask:
     payload: Optional[Any] = None
 
 
+class _PickleSafeTracebackFormatterConnector(Connector[Callable[[BaseException], str]]):
+    name = "PickleSafeTraceBackFormatter"
+    ep_name = "pickle_safe_traceback_formatter"
+
+    def _get_default(self) -> Callable[[], Callable[[BaseException], str]]:
+        def wrapper():
+            return lambda x: "".join(traceback.format_exception(x))
+
+        return wrapper
+
+
+pickle_safe_traceback_formatter_connector = _PickleSafeTracebackFormatterConnector()
+
+
 class PickleSafeException(Exception):
     """An exception that can be safely pickled and passed between processes."""
 
@@ -59,9 +74,14 @@ class PickleSafeException(Exception):
         pretty_lines.append(self.formatted_output)
         return "\n".join(pretty_lines)
 
-    @staticmethod
-    def from_exc(orig_exc: Exception, device_id: str, formatted_output: str) -> "PickleSafeException":
-        return PickleSafeException(orig_exc.__class__, str(orig_exc), device_id, formatted_output)
+    @classmethod
+    def from_exc(cls, orig_exc: Exception, device_id: str) -> "PickleSafeException":
+        return PickleSafeException(
+            orig_exc.__class__,
+            str(orig_exc),
+            device_id,
+            pickle_safe_traceback_formatter_connector.get()(orig_exc)
+        )
 
 
 @catch_ctrl_c
@@ -136,12 +156,6 @@ def _pool_worker(pool, index, task_queue, done_queue):
                 capture_output_ctx = capture_output(cap_stdout, cap_stderr)
 
                 with invoke_span_ctx as invoke_span, capture_output_ctx as _:
-                    invoke_trace_id = invoke_span.get_span_context().trace_id
-                    if invoke_trace_id:
-                        span.set_attribute(
-                            "link",
-                            f"https://t.yandex-team.ru/trace/{invoke_trace_id:x}"
-                        )
                     invoke_span.set_attribute("func", pool.func.__name__)
                     invoke_span.set_attribute("worker.id", worker_id)
                     if device_id:
@@ -164,7 +178,7 @@ def _pool_worker(pool, index, task_queue, done_queue):
         except KeyboardInterrupt:  # pylint: disable=try-except-raise
             raise
         except Exception as exc:
-            safe_exc = PickleSafeException.from_exc(exc, task.payload, traceback.format_exc())
+            safe_exc = PickleSafeException.from_exc(exc, task.payload)
             ret_exc = safe_exc
             task_result.exc = safe_exc
             task_result.result = None
@@ -301,11 +315,10 @@ class Parallel:
                             **self.kwargs
                         )
                 except Exception as exc:
+                    safe_exc = PickleSafeException.from_exc(exc, device_id)
                     if not tolerate_fails:
-                        raise
-                    exc.device_id = device_id
-                    exc.formatted_output = traceback.format_exc()
-                    task_result.exc = exc
+                        raise safe_exc
+                    task_result.exc = safe_exc
                 if self.capture_output:
                     task_result.extra["cap_stdout"] = cap_stdout.read()
                     task_result.extra["cap_stderr"] = cap_stderr.read()
