@@ -5,11 +5,12 @@ from typing import Iterable, Union
 
 from annet.annlib.lib import mako_render
 from annet.annlib.rbparser.ordering import compile_ordering_text
-from annet.annlib.rbparser.platform import VENDOR_REVERSES, VENDOR_ALIASES
+from annet.annlib.rbparser.platform import VENDOR_ALIASES
 
 from annet.connectors import CachedConnector
 from annet.rulebook.deploying import compile_deploying_text
 from annet.rulebook.patching import compile_patching_text
+from annet.vendors import registry_connector
 
 
 class RulebookProvider(ABC):
@@ -63,7 +64,7 @@ class DefaultRulebookProvider(RulebookProvider):
         if hw in self._rulebook_cache:
             return self._rulebook_cache[hw]
 
-        assert hw.vendor in VENDOR_REVERSES, "Unknown vendor: %s" % (hw.vendor)
+        assert hw.vendor in registry_connector.get(), "Unknown vendor: %s" % (hw.vendor)
         rul_vendor_name = VENDOR_ALIASES.get(hw.vendor, hw.vendor)
         patching = compile_patching_text(self._render_rul(rul_vendor_name + ".rul", hw), rul_vendor_name)
 
@@ -98,7 +99,7 @@ class DefaultRulebookProvider(RulebookProvider):
             return self._escaped_rul_cache[name]
         for root_dir in self.root_dir:
             try:
-                with open(path.join(root_dir, "texts", name), "r") as f:
+                with open(path.join(root_dir, "texts", name), "r", encoding="utf-8") as f:
                     self._escaped_rul_cache[name] = self._escape_mako(f.read())
                     return self._escaped_rul_cache[name]
             except FileNotFoundError:
