@@ -48,12 +48,12 @@ def no_ntp_distribute(rule, key, diff, **_):
     yield from common.default(rule, key, diff)
 
 
-def banner_login(rule, key, diff, **_):
-    if diff[Op.REMOVED]:
-        yield (False, "no banner login", None)
-    elif diff[Op.ADDED]:
+def banner_any(rule, key, diff, **_):
+    if diff[Op.ADDED]:
         # Убираем дополнительный экранирующий сиимвол
-        key = re.sub(r"\^C", "^", key[0])
-        yield (False, f"banner login {key}", None)
+        banner = re.sub(r"\^C", "^", diff[Op.ADDED][0]["row"])
+        yield (False, banner, None)
+    elif diff[Op.REMOVED]:
+        yield (False, f"no banner {key[0]}", None)
     else:
         yield from common.default(rule, key, diff)
