@@ -487,7 +487,7 @@ class JuniperFormatter(CommonFormatter):
 
         self._sub_regexs = (
             (re.compile(self._block_begin + r"\s*" + self._block_end + r"$"), ""),  # collapse empty blocks
-            (re.compile(self._block_begin + "(\t# .+)?$"), ""),
+            (re.compile(self._block_begin + r"\s*" + r"(\t# .+)?$"), ""),
             (re.compile(self._statement_end + r"$"), ""),
             (re.compile(r"\s*" + self._block_end + "(\t# .+)?$"), ""),
             (re.compile(self._endofline_comment + r".*$"), ""),
@@ -694,46 +694,35 @@ class RosFormatter(CommonFormatter):
         is_patch: bool,
         context: Optional[FormatterContext] = None
     ):
+        if is_patch:
+            raise RuntimeError("Ros not supported blocks in patch")
+
         rows = []
 
-        if is_patch:
-            items = ((item.row, item.child, item.context) for item in tree.itms)
-        else:
-            items = ((row, child, {}) for row, child in tree.items())
-
+        items = ((row, child, {}) for row, child in tree.items())
         for row, sub_config, row_context in items:
-            if sub_config or (is_patch and sub_config is not None):
-                rows.append((row, sub_config, row_context))
-            else:
-                rows.append((row, None, row_context))
+            rows.append((row, sub_config if sub_config else None, row_context))
 
-        prev_prow = None
-        prev_prow_context = {}
         for sub_config, row_group in itertools.groupby(rows, lambda x: x[1]):
             if sub_config is None:
-                if prev_prow:
-                    yield prev_prow, prev_prow_context
-                    yield BlockBegin, None
+                blocks, leaf = [], context
+                while leaf:
+                    if leaf.current:
+                        blocks.append(leaf.current[0])
+                    leaf = leaf.parent
+
+                yield " ".join(reversed(blocks)), None
+                yield BlockBegin, None
                 for row, _, row_context in row_group:
                     yield row, row_context
-                if prev_prow:
-                    yield BlockEnd, None
+                yield BlockEnd, None
             else:
                 for row, _, row_context in row_group:
-                    if context and context.parent and context.parent.row:
-                        prev_prow, prev_prow_context = context.parent.current
-                        prow = f"{context.parent.row} {row}"
-                    else:
-                        prow = row
-                    yield prow, row_context
-
-                    yield BlockBegin, None
                     yield from self.blocks_and_context(
                         sub_config,
                         is_patch,
-                        context=FormatterContext(parent=context, current=(prow, row_context))
+                        context=FormatterContext(parent=context, current=(row, row_context))
                     )
-                    yield BlockEnd, None
 
     def _formatted_blocks(self, blocks):
         line = None
@@ -823,41 +812,23 @@ class RosFormatter(CommonFormatter):
             (re.compile(r"^add "), ""),
             (re.compile(r"^print file="), "name="),
         )
-        patch_items = []
+
+        commands = odict()
         for item in patch.itms:
             key, childs, context = item.row, item.child, item.context
             if childs:
-                patch_items.append((key, childs, context))
+                childs_prev = f"{_prev} {key.strip()}".lstrip()
+                commands.update(self.cmd_paths(childs, _prev=childs_prev))
             else:
-                patch_items.append((key, None, context))
+                if key.startswith("remove"):
+                    find_cmd = key.removeprefix("remove").strip()
+                    for regex, repl_line in rm_regexs:
+                        find_cmd = regex.sub(repl_line, find_cmd)
+                    cmd = f"/{_prev} remove [ find {find_cmd} ]"
+                else:
+                    cmd = f"/{_prev} {key}"
+                commands[(cmd,)] = context
 
-        commands = odict()
-        prev_cmd = None
-        prev_context = None
-        for childs, items in itertools.groupby(patch_items, lambda x: x[1]):
-            if childs is None:
-                if prev_cmd:
-                    commands[(prev_cmd,)] = prev_context
-                for key, _, context in items:
-                    if key.startswith("remove"):
-                        find_cmd = key.replace("remove", "", 1).strip()
-                        for (regex, repl_line) in rm_regexs:
-                            find_cmd = regex.sub(repl_line, find_cmd)
-                        cmd = "remove [ find " + find_cmd + " ]"
-                    else:
-                        cmd = key
-                    commands[(cmd,)] = context
-            else:
-                for key, _, context in items:
-                    if _prev:
-                        prev_cmd = _prev
-                        prev_context = context
-                        block_cmd = f"{_prev} {key}"
-                    else:
-                        block_cmd = f"/{key}"
-                    commands[(block_cmd,)] = context
-                    for k, v in self.cmd_paths(childs, block_cmd).items():
-                        commands[k] = v
         return commands
 
 
